@@ -17,8 +17,8 @@ def run_alice():
         i = array.get_future_index(0)
         j = array.get_future_index(1)
 
-        def outer_body(alice):
-            def inner_body(alice):
+        def outer_body(alice, _):
+            def inner_body(alice, _):
                 q = Qubit(alice)
                 q.free()
                 j.add(1)
@@ -39,3 +39,7 @@ def test_nested_loop():
         ]
     )
     simulate_application(app_instance, use_app_config=False, enable_logging=False)
+
+
+if __name__ == "__main__":
+    test_nested_loop()
